@@ -12,22 +12,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee',
+ 'BASECFLAGS': '-fno-strict-aliasing -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python3.5',
  'BLDLIBRARY': '-L. -lpython3.5m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+              '-L/usr/obj/ports/Python-3.5.2/Python-3.5.2',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'alpha-unknown-openbsd5.9',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd6.1',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee '
-           '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
+ 'CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC -O2 '
+           '-pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
@@ -37,9 +37,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.5.1/Python-3.5.1' "
+                "'--srcdir=/usr/obj/ports/Python-3.5.2/Python-3.5.2' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
-                "'--with-cxx_main' '--with-system-expat' '--with-system-ffi' "
+                "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
                 "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
                 "'--localstatedir=/var' '--disable-silent-rules' "
@@ -47,9 +47,9 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.5m',
- 'COREPYTHONPATH': ':plat-openbsd5',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.5.1/Python-3.5.1/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.5.1/Python-3.5.1/lcov-report',
+ 'COREPYTHONPATH': ':plat-openbsd6',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.5.2/Python-3.5.2/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.5.2/Python-3.5.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
@@ -91,7 +91,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -181,8 +181,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -232,7 +232,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -252,6 +252,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
@@ -316,6 +317,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -382,7 +384,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRUCT_STAT_ST_GEN': 1,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYMLINKAT': 1,
  'HAVE_SYNC': 1,
@@ -465,27 +466,27 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'alpha-unknown-openbsd5.9',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.1',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.5m '
                    '/usr/local/include/python3.5m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.5m',
- 'INSTALL': '/usr/obj/ports/Python-3.5.1/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.5.1/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.5.1/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.5.1/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.5.1/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-3.5.2/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.5.2/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.5.2/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.5.2/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.5.2/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.5m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.2/Python-3.5.2',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+             '-L/usr/obj/ports/Python-3.5.2/Python-3.5.2',
  'LDVERSION': '3.5m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.5',
@@ -501,7 +502,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'c++ -pthread',
+ 'LINKCC': 'cc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -509,14 +510,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LLVM_PROF_MERGER': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
- 'LOG1P_DROPS_ZERO_SIGN': 0,
- 'MACHDEP': 'openbsd5',
- 'MACHDEPPATH': ':plat-openbsd5',
- 'MACHDEPS': 'plat-openbsd5',
+ 'LOG1P_DROPS_ZERO_SIGN': 1,
+ 'MACHDEP': 'openbsd6',
+ 'MACHDEPPATH': ':plat-openbsd6',
+ 'MACHDEPS': 'plat-openbsd6',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/local/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'c++ -pthread',
+ 'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
@@ -567,10 +568,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGO_PROF_GEN_FLAG': '',
  'PGO_PROF_USE_FLAG': '',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-openbsd5',
+ 'PLATDIR': 'plat-openbsd6',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -581,21 +585,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-openbsd5',
+ 'PYTHONPATH': ':plat-openbsd6',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee '
-              '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
+ 'PY_CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC '
+              '-O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code '
-                   '-mieee -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+ 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   '
+                   '-fPIC -O2 -pipe -O2 -pipe '
                    '-Werror=declaration-after-statement -I. -IInclude '
                    '-I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.2/Python-3.5.2',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -604,7 +608,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.2/Python-3.5.2',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -618,17 +622,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-35m',
@@ -641,15 +645,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TANH_PRESERVES_ZERO_SIGN': 1,
+ 'TANH_PRESERVES_ZERO_SIGN': 0,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.2/Python-3.5.2 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.2/Python-3.5.2 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -672,10 +676,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.5.1/Python-3.5.1',
- 'abs_srcdir': '/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'abs_builddir': '/usr/obj/ports/Python-3.5.2/Python-3.5.2',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.5.2/Python-3.5.2',
+ 'cross_compiling': 'no',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
